/* sanebuttond -- SANE button monitoring daemon
   Using the SANE library.
   Copyright (C) 2004 Rene Rebe, rene@rocklinux.org
   Copyright (C) 2005 Gerhard Jger, gerhard@gjaeger.de
   Copytight (C) 2006 Jean-Christophe Cardot, jice@cardot.net

   Code based on Rene Rebes' scanbuttond.cc
   
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program;a if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  
*/

/* Compile with:
   gcc `sane-config --libs -cflags` sane-list-scanners.c  -o sane-list-scanners */

#include <assert.h>
#include <getopt.h>
#include <signal.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <stdarg.h>

#include <sys/types.h>
#include <sys/stat.h>

#include <sane/sane.h>

#define MAX_BUTTONS 20

static SANE_Handle device;

int
main (int argc, char **argv)
{
	int i, idx;
	const SANE_Option_Descriptor *opt;
	const SANE_Device **device_list;
	SANE_Int val;
	SANE_Int num_dev_options = 0;
	SANE_Int button_list[MAX_BUTTONS];

	SANE_Status status;
	SANE_Int version_code;

	sane_init (&version_code, 0);

	//printf( "Scanning for devices ...\n" );
	status = sane_get_devices (&device_list, SANE_FALSE);
	if (status != SANE_STATUS_GOOD) {
		fprintf( stderr, "sane_get_devices() failed: %s\n", 
		         sane_strstatus(status));
		return 1;
	}
	if (!device_list[0]) {
		fprintf( stderr, " no SANE devices found!\n" );
		return 1;
	}

	i = 0;
	while(device_list[i]) {
		printf( "%s %s %s\n", 	device_list[i]->name,
					device_list[i]->vendor,
			        	device_list[i]->model );
		i++;
	}
  
	return 0;
}
